@@ -13,20 +13,28 @@ import time
 from abc import abstractmethod
 from contextlib import suppress
 from functools import cached_property
-from importlib import import_module
 from importlib.util import MAGIC_NUMBER
 from pathlib import Path
+from pkgutil import resolve_name
 from typing import TYPE_CHECKING, Any
 from zipfile import ZIP_DEFLATED, ZIP_STORED, PyZipFile, ZipFile, ZipInfo
 
 from setuptools import Distribution
 
-from cx_Freeze._compat import IS_MACOS, IS_MINGW, IS_WINDOWS, PYTHON_VERSION
+from cx_Freeze._compat import (
+    ABI_THREAD,
+    BUILD_EXE_DIR,
+    IS_CONDA,
+    IS_MACOS,
+    IS_MINGW,
+    IS_WINDOWS,
+    PYTHON_VERSION,
+)
 from cx_Freeze.common import get_resource_file_path, process_path_specs
 from cx_Freeze.exception import FileError, OptionError
 from cx_Freeze.executable import Executable
 from cx_Freeze.finder import ModuleFinder
-from cx_Freeze.module import ConstantsModule, Module
+from cx_Freeze.module import ConstantsModule, DistributionCache, Module
 from cx_Freeze.parser import ELFParser, Parser, PEParser
 
 if TYPE_CHECKING:
@@ -42,6 +50,28 @@ elif IS_MACOS:
 
 __all__ = ["ConstantsModule", "Executable", "Freezer"]
 
+WARNING_PIP_CX_FREEZE_IN_CONDA_PYTHON = """WARNING:
+
+    It is not recommended to use cx_Freeze installed from pip with conda \
+python.
+    To install cx_Freeze as conda package (cx_freeze):
+        pip uninstall cx_Freeze
+        conda install conda-forge::cx_freeze
+
+    To fix this issue, refer to the documentation:
+        \
+https://cx-freeze.readthedocs.io/en/stable/installation.html#conda-forge
+
+    On macOS, you should get an error shortly.
+"""
+
+WARNING_USING_PYTHON_FROM_MS_STORE = """WARNING:
+
+    Because of restrictions on Microsoft Store apps, Python scripts may not \
+have full write access to built executable.
+    You will need to install the full installer.
+"""
+
 
 class Freezer:
     """Freezer base class."""
@@ -78,6 +108,7 @@ class Freezer:
         silent: bool | int = 0,
         metadata: Any = None,
         include_msvcr: bool = False,
+        include_msvcr_version: str | None = None,
         zip_include_packages: Sequence[str] | None = None,
         zip_exclude_packages: Sequence[str] | None = None,
         zip_filename: Path | str | None = None,
@@ -97,6 +128,7 @@ class Freezer:
         self.path: list[str] | None = self._validate_path(path)
         # include-msvcr is used on Windows, but not in MingW
         self.include_msvcr: bool = IS_WINDOWS and bool(include_msvcr)
+        self.include_msvcr_version: str | None = include_msvcr_version
         self.target_dir = target_dir
         self.default_bin_includes: list[str] = self._default_bin_includes()
         self.default_bin_excludes: list[str] = self._default_bin_excludes()
@@ -139,6 +171,7 @@ class Freezer:
         self.files_copied: set[Path] = set()
         self.modules_copied: list[Module] = []
         self.finder: ModuleFinder = self._get_module_finder()
+        self._check_installation()
 
     @property
     def target_dir(self) -> Path:
@@ -148,9 +181,7 @@ class Freezer:
     @target_dir.setter
     def target_dir(self, path: str | Path | None) -> None:
         if path is None:
-            platform = sysconfig.get_platform()
-            python_version = sysconfig.get_python_version()
-            path = f"build/exe.{platform}-{python_version}"
+            path = BUILD_EXE_DIR
         path = Path(os.path.abspath(path)).resolve()
         if os.fspath(path) in self.path:
             msg = "the build_exe directory cannot be used as search path"
@@ -176,6 +207,12 @@ class Freezer:
         target_icon = self.target_dir / exe.icon.name
         self._copy_file(exe.icon, target_icon, copy_dependent_files=False)
 
+    def _check_installation(self) -> None:
+        if IS_CONDA:
+            dist = DistributionCache(self.finder.cache_path, "cx_Freeze")
+            if dist.installer == "pip":
+                print(WARNING_PIP_CX_FREEZE_IN_CONDA_PYTHON, file=sys.stderr)
+
     def _copy_file(
         self,
         source: Path,
@@ -256,10 +293,7 @@ class Freezer:
         """
         real_source = source.resolve()
         if source.is_symlink():
-            try:
-                symlink = source.readlink()
-            except AttributeError:
-                symlink = Path(os.readlink(source))  # python 3.8
+            symlink = source.readlink()
             real_target = target.with_name(symlink.name)
             if self.silent < 1:
                 print(f"[delay] linking {target} -> {symlink}")
@@ -292,6 +326,7 @@ class Freezer:
         finder.include_file_as_module(
             get_resource_file_path("initscripts", "__startup__", ".py")
         )
+
         # copy the executable and its dependencies
         target_path = self.target_dir / exe.target_name
         self._get_top_dependencies(exe.base)
@@ -323,13 +358,6 @@ class Freezer:
     def _get_top_dependencies(self, source: Path, target: Path) -> None:
         """Called to get the dependencies of an executable."""
 
-    def _platform_add_extra_dependencies(
-        self, dependent_files: set[Path]
-    ) -> None:
-        """Override with platform specific files to add runtime libraries to
-        the list of dependent_files calculated in _freeze_executable.
-        """
-
     @abstractmethod
     def _default_bin_excludes(self) -> list[str]:
         """Return the file names of libraries that need not be included because
@@ -372,9 +400,7 @@ class Freezer:
         bin_path = [
             sysconfig.get_config_var("LIBDIR"),
             sysconfig.get_config_var("DESTLIB"),
-            Path(  # uv python
-                sys.base_prefix, getattr(sys, "platlibdir", "lib")
-            ),
+            Path(sys.base_prefix, sys.platlibdir),  # uv python
         ]
         return self._validate_bin_path(bin_path)
 
@@ -454,18 +480,10 @@ class Freezer:
 
         # check the path for inclusion/exclusion
         for binpath in self.bin_path_includes:
-            try:
-                dirname.relative_to(binpath)
-            except ValueError:
-                pass
-            else:
+            if dirname.is_relative_to(binpath):
                 return True
         for binpath in self.bin_path_excludes:
-            try:
-                dirname.relative_to(binpath)
-            except ValueError:
-                pass
-            else:
+            if dirname.is_relative_to(binpath):
                 return False
 
         # check the default variables
@@ -476,18 +494,10 @@ class Freezer:
             if filename_noversion.match(binfile):
                 return False
         for binpath in self.default_bin_path_includes:
-            try:
-                dirname.relative_to(binpath)
-            except ValueError:
-                pass
-            else:
+            if dirname.is_relative_to(binpath):
                 return True
         for binpath in self.default_bin_path_excludes:
-            try:
-                dirname.relative_to(binpath)
-            except ValueError:
-                pass
-            else:
+            if dirname.is_relative_to(binpath):
                 return False
 
         return True
@@ -850,8 +860,7 @@ class WinFreezer(Freezer, PEParser):
                 if self.silent < 3:
                     print(warning_msg, "version must be specified")
             else:
-                winversioninfo = import_module("cx_Freeze.winversioninfo")
-                version = winversioninfo.VersionInfo(
+                version = resolve_name("cx_Freeze.winversioninfo:VersionInfo")(
                     self.metadata.version,
                     comments=self.metadata.long_description,
                     description=self.metadata.description,
@@ -885,12 +894,7 @@ class WinFreezer(Freezer, PEParser):
                     if "\\WindowsApps\\" in sys.base_prefix:
                         if self.silent < 3:
                             print("WARNING:", exc)
-                            print(
-                                "WARNING: Because of restrictions on "
-                                "Microsoft Store apps, Python scripts may not "
-                                "have full write access to built executable. "
-                                "You will need to install the full installer."
-                            )
+                            print(WARNING_USING_PYTHON_FROM_MS_STORE)
                     else:
                         raise
 
@@ -935,15 +939,6 @@ class WinFreezer(Freezer, PEParser):
             if self.silent < 3:
                 print("WARNING:", exc)
 
-    def _pre_copy_hook(self, source: Path, target: Path) -> tuple[Path, Path]:
-        """Prepare the source and target paths. Also, adjust the target of
-        C runtime libraries.
-        """
-        # fix the target path for C runtime files
-        if any(filter(target.match, self.runtime_files)):
-            target = self.target_dir / target.name
-        return super()._pre_copy_hook(source, target)
-
     def _post_copy_hook(
         self,
         source: Path,
@@ -973,6 +968,8 @@ class WinFreezer(Freezer, PEParser):
                 # this is possible with most packages installed by pip
                 try:
                     relative = dependent_source.relative_to(source_dir)
+                    # dependency located with source or in a subdirectory
+                    dependent_target = target_dir / relative
                 except ValueError:
                     # check if dependency is on default binaries path
                     dependent_srcdir = dependent_source.parent
@@ -987,14 +984,9 @@ class WinFreezer(Freezer, PEParser):
                             dependent_target = Path(*parts) / dependent_name
                         except ValueError:
                             dependent_target = target_dir / dependent_name
-                else:
-                    # dependency located with source or in a subdirectory
-                    dependent_target = target_dir / relative
                 # make sure the dependency is in the correct directory because
                 # it cannot be outside the library_dir directory subtree
-                try:
-                    dependent_target.relative_to(library_dir)
-                except ValueError:
+                if not dependent_target.is_relative_to(library_dir):
                     dependent_target = library_dir / dependent_name
                 if 0:  # else:
                     _, dependent_target = self._pre_copy_hook(
@@ -1009,8 +1001,35 @@ class WinFreezer(Freezer, PEParser):
                 dependent_source, dependent_target, copy_dependent_files
             )
 
+    def _post_freeze_hook(self) -> None:
+        if self.include_msvcr:
+            from cx_Freeze.winmsvcr_repack import get_msvcr_files
+
+            # remove MSVC runtime from default excludes
+            excludes = set(self.default_bin_excludes)
+            runtime = self._runtime_files()
+            self.default_bin_excludes = list(excludes.difference(runtime))
+
+            # copy the MSVC runtime files
+            target_dir = self.target_dir
+            license_dir = target_dir / "share/licenses/vc_redist"
+            for source in get_msvcr_files(self.include_msvcr_version):
+                if source.stem == "LICENSE":
+                    target = license_dir / source.name
+                else:
+                    target = target_dir / source.name
+                self._copy_file(source, target, copy_dependent_files=False)
+
+    def _runtime_files(self) -> set[str]:
+        """Deal with C-runtime files."""
+        from cx_Freeze.winmsvcr import MSVC_FILES, UCRT_FILES
+
+        return [*MSVC_FILES, *UCRT_FILES]
+
     def _default_bin_excludes(self) -> list[str]:
-        return ["comctl32.dll", "oci.dll"]
+        # MSVC runtime files are also on the exclusion list, but can still be
+        # added on demand in _post_freeze_hook
+        return ["comctl32.dll", "oci.dll", *self._runtime_files()]
 
     def _default_bin_includes(self) -> list[str]:
         name = sysconfig.get_config_var("INSTSONAME")
@@ -1018,9 +1037,10 @@ class WinFreezer(Freezer, PEParser):
             # MSYS2 python returns a static library.
             names = [name.replace(".dll.a", ".dll")]
         else:
+            py_version = f"{PYTHON_VERSION}{ABI_THREAD}"
             names = [
                 f"python{sys.version_info[0]}.dll",
-                f"python{PYTHON_VERSION.replace('.', '')}.dll",
+                f"python{py_version.replace('.', '')}.dll",
             ]
         python_shared_libs: list[Path] = []
         for name in names:
@@ -1044,13 +1064,15 @@ class WinFreezer(Freezer, PEParser):
         # msys2 libpython depends on libgcc_s_seh and libwinpthread dlls
         # conda-forge python3x.dll depends on zlib.dll
         lib_files = self.finder.lib_files
-        for path in map(Path, self.default_bin_includes):
-            lib_files.setdefault(path, path.name)
         for filename in self.get_dependent_files(source):
             path = filename.resolve()
             if path not in lib_files and self._should_copy_file(path):
                 lib_files.setdefault(path, path.name)
                 self._get_top_dependencies(path)
+        if not IS_MINGW:
+            # abi3 packages requires python3.dll (windows/conda windows)
+            for path in map(Path, self.default_bin_includes):
+                lib_files.setdefault(path, path.name)
 
     @cached_property
     def _platform_bin_path(self) -> list[Path]:
@@ -1078,29 +1100,6 @@ class WinFreezer(Freezer, PEParser):
         # return only valid paths
         return [path.resolve() for path in paths if path.is_dir()]
 
-    def _platform_add_extra_dependencies(
-        self, dependent_files: set[Path]
-    ) -> None:
-        search_dirs: set[Path] = set()
-        for filename in dependent_files:
-            search_dirs.add(filename.parent)
-        for search_dir in search_dirs:
-            for pattern in self.runtime_files:
-                for filename in search_dir.glob(pattern):
-                    filepath = search_dir / filename
-                    if filepath.exists():
-                        dependent_files.add(filepath)
-
-    @cached_property
-    def runtime_files(self) -> set[str]:
-        """Deal with C-runtime files."""
-        winmsvcr = import_module("cx_Freeze.winmsvcr")
-        if not self.include_msvcr:
-            # just put on the exclusion list
-            self.bin_excludes.extend(winmsvcr.FILES)
-            return set()
-        return set(winmsvcr.FILES)
-
 
 class DarwinFreezer(Freezer, Parser):
     """Freezer base class for macOS."""
@@ -1121,7 +1120,7 @@ class DarwinFreezer(Freezer, Parser):
     def _default_bin_includes(self) -> list[str]:
         python_shared_libs: list[Path] = []
         # Check for distributed "cx_Freeze/bases/lib/Python"
-        name = "Python"
+        name = f"Python{ABI_THREAD.upper()}"
         for bin_path in self._default_bin_path_includes():
             fullname = Path(bin_path, name).resolve()
             if fullname.is_file():
@@ -1269,10 +1268,8 @@ class DarwinFreezer(Freezer, Parser):
     def get_dependent_files(
         self, filename: Path, darwinFile: DarwinFile | None = None
     ) -> set[Path]:
-        try:
+        with suppress(KeyError):
             return self.dependent_files[filename]
-        except KeyError:
-            pass
 
         # if darwinFile is None (which means that get_dependent_files is
         # being called outside of _copy_file -- e.g., one of the
@@ -1376,6 +1373,8 @@ class LinuxFreezer(Freezer, ELFParser):
                 # this is possible with most packages installed by pip
                 try:
                     relative = dependent_source.relative_to(source_dir)
+                    # dependency located with source or in a subdirectory
+                    dependent_target = target_dir / relative
                 except ValueError:
                     # put the dependency in target_dir along with the binary
                     # file being copied, unless the dependency has already been
@@ -1386,16 +1385,12 @@ class LinuxFreezer(Freezer, ELFParser):
                         if file.name == dependent_name:
                             try:
                                 relative = file.relative_to(target_dir)
+                                dependent_target = file
                             except ValueError:
                                 relative = Path(
                                     os.path.relpath(file, target_dir)
                                 )
-                            else:
-                                dependent_target = file
                             break
-                else:
-                    # dependency located with source or in a subdirectory
-                    dependent_target = target_dir / relative
             fix_rpath.add(f"$ORIGIN/{relative.parent.as_posix()}")
             self._copy_file(
                 dependent_source, dependent_target, copy_dependent_files
