@@ -281,8 +281,8 @@ hello.py
     print()
 setup.py
     from plist_data import BUILD_DIR, BUNDLE_NAME, TEST_KEY, TEST_VALUE
-    from cx_Freeze import Executable, setup
-    executables = [Executable("hello.py")]
+    from cx_Freeze import setup
+    executables = ["hello.py"]
     setup(
         name="hello",
         version="0.1",
@@ -548,7 +548,7 @@ def run_command(
         if cxfreeze:
             command[0] = cxfreeze
         else:
-            command = "python -m cx_Freeze".split() + command[1:]
+            command = ["python", "-m", "cx_Freeze"] + command[1:]
     if command[0] == "python":
         command[0] = sys.executable
     return check_output(
