@@ -10,8 +10,9 @@ from typing import NoReturn
 import pytest
 from generate_samples import create_package, run_command
 
-from cx_Freeze import Executable, Freezer
+from cx_Freeze import Freezer
 from cx_Freeze._compat import (
+    ABI_THREAD,
     BUILD_EXE_DIR,
     EXE_SUFFIX,
     IS_CONDA,
@@ -35,7 +36,7 @@ def test_freezer_target_dir_empty(tmp_path: Path, monkeypatch) -> None:
     create_package(tmp_path, SOURCE)
     monkeypatch.chdir(tmp_path)
 
-    freezer = Freezer(executables=[Executable("hello.py")])
+    freezer = Freezer(executables=["hello.py"])
     target_dir = tmp_path / BUILD_EXE_DIR
     assert freezer.target_dir == target_dir
 
@@ -45,7 +46,7 @@ def test_freezer_target_dir_dist(tmp_path: Path, monkeypatch) -> None:
     create_package(tmp_path, SOURCE)
     monkeypatch.chdir(tmp_path)
 
-    freezer = Freezer(executables=[Executable("hello.py")], target_dir="dist")
+    freezer = Freezer(executables=["hello.py"], target_dir="dist")
     target_dir = tmp_path / "dist"
     assert freezer.target_dir == target_dir
 
@@ -56,9 +57,7 @@ def test_freezer_target_dir_utf8(tmp_path: Path, monkeypatch) -> None:
     monkeypatch.chdir(tmp_path)
 
     target_dir = tmp_path / "ação"
-    freezer = Freezer(
-        executables=[Executable("hello.py")], target_dir=target_dir
-    )
+    freezer = Freezer(executables=["hello.py"], target_dir=target_dir)
     assert freezer.target_dir == target_dir
 
 
@@ -73,9 +72,7 @@ def test_freezer_target_dir_in_path(tmp_path: Path, monkeypatch) -> None:
         OptionError,
         match="the build_exe directory cannot be used as search path",
     ):
-        Freezer(
-            executables=[Executable("hello.py")], path=[*sys.path, target_dir]
-        )
+        Freezer(executables=["hello.py"], path=[*sys.path, target_dir])
 
 
 def test_freezer_target_dir_locked(tmp_path: Path, monkeypatch) -> None:
@@ -94,7 +91,7 @@ def test_freezer_target_dir_locked(tmp_path: Path, monkeypatch) -> None:
     with pytest.raises(
         OptionError, match="the build_exe directory cannot be cleaned"
     ):
-        Freezer(executables=[Executable("hello.py")], target_dir=target_dir)
+        Freezer(executables=["hello.py"], target_dir=target_dir)
 
 
 def test_freezer_default_bin_includes(tmp_path: Path, monkeypatch) -> None:
@@ -102,20 +99,21 @@ def test_freezer_default_bin_includes(tmp_path: Path, monkeypatch) -> None:
     create_package(tmp_path, SOURCE)
     monkeypatch.chdir(tmp_path)
 
-    freezer = Freezer(executables=[Executable("hello.py")])
+    freezer = Freezer(executables=["hello.py"])
+    py_version = f"{PYTHON_VERSION}{ABI_THREAD}"
     if IS_MINGW:
-        expected = f"libpython{PYTHON_VERSION}.dll"
+        expected = f"libpython{py_version}.dll"
     elif IS_WINDOWS:
-        expected = f"python{PYTHON_VERSION.replace('.', '')}.dll"
+        expected = f"python{py_version.replace('.', '')}.dll"
     elif IS_CONDA:  # macOS or Linux
         if IS_MACOS:
-            expected = f"libpython{PYTHON_VERSION}.dylib"
+            expected = f"libpython{py_version}.dylib"
         else:
-            expected = f"libpython{PYTHON_VERSION}.so*"
+            expected = f"libpython{py_version}.so*"
     elif IS_MACOS:
-        expected = "Python"
+        expected = f"Python{ABI_THREAD.upper()}"
     elif ENABLE_SHARED:  # Linux
-        expected = f"libpython{PYTHON_VERSION}.so*"
+        expected = f"libpython{py_version}.so*"
     else:
         assert freezer.default_bin_includes == []
         return
@@ -141,7 +139,7 @@ def test_freezer_populate_zip_options_invalid_values(
         OptionError, match="all packages cannot be included and excluded "
     ):
         Freezer(
-            executables=[Executable("hello.py")],
+            executables=["hello.py"],
             zip_include_packages=["*"],
             zip_exclude_packages=["*"],
         )
@@ -149,7 +147,7 @@ def test_freezer_populate_zip_options_invalid_values(
     # zip_include_packages and zip_exclude_packages has the same package
     with pytest.raises(OptionError, match="package 'tkinter' cannot be both"):
         Freezer(
-            executables=[Executable("hello.py")],
+            executables=["hello.py"],
             zip_include_packages=["tkinter"],
             zip_exclude_packages=["tkinter"],
         )
@@ -157,7 +155,7 @@ def test_freezer_populate_zip_options_invalid_values(
         OptionError, match="packages 'tkinter, unittest' cannot be both"
     ):
         Freezer(
-            executables=[Executable("hello.py")],
+            executables=["hello.py"],
             zip_include_packages=["tkinter", "unittest"],
             zip_exclude_packages=["tkinter", "unittest", "codeop"],
         )
@@ -272,7 +270,7 @@ def test_freezer_options(
     create_package(tmp_path, SOURCE)
     monkeypatch.chdir(tmp_path)
 
-    freezer = Freezer(executables=[Executable("hello.py")], **kwargs)
+    freezer = Freezer(executables=["hello.py"], **kwargs)
     for option, value in expected.items():
         assert getattr(freezer, option) == value
 
@@ -332,9 +330,7 @@ def test_freezer_zip_filename(
     create_package(tmp_path, SOURCE)
     monkeypatch.chdir(tmp_path)
 
-    freezer = Freezer(
-        executables=[Executable("hello.py")], silent=True, **kwargs
-    )
+    freezer = Freezer(executables=["hello.py"], silent=True, **kwargs)
     target_dir = freezer.target_dir
 
     freezer.freeze()
